<?php

if (!function_exists('array_column')) {

    /**
     * Returns the values from a single column of the input array, identified by
     * the $columnKey.
     *
     * Optionally, you may provide an $indexKey to index the values in the returned
     * array by the values from the $indexKey column in the input array.
     *
     * @param array $input A multi-dimensional array (record set) from which to pull
     *                     a column of values.
     * @param mixed $columnKey The column of values to return. This value may be the
     *                         integer key of the column you wish to retrieve, or it
     *                         may be the string key name for an associative array.
     * @param mixed $indexKey (Optional) The column to use as the index/keys for
     *                        the returned array. This value may be the integer key
     *                        of the column, or it may be the string key name.
     * @return array
     */
    function array_column($input = null, $columnKey = null, $indexKey = null)
    {
        // Using func_get_args() in order to check for proper number of
        // parameters and trigger errors exactly as the built-in array_column()
        // does in PHP 5.5.
        $argc = func_num_args();
        $params = func_get_args();

        if ($argc < 2) {
            trigger_error("array_column() expects at least 2 parameters, {$argc} given", E_USER_WARNING);
            return null;
        }

        if (!is_array($params[0])) {
            trigger_error('array_column() expects parameter 1 to be array, ' . gettype($params[0]) . ' given', E_USER_WARNING);
            return null;
        }

        if (!is_int($params[1])
            && !is_float($params[1])
            && !is_string($params[1])
            && $params[1] !== null
            && !(is_object($params[1]) && method_exists($params[1], '__toString'))
        ) {
            trigger_error('array_column(): The column key should be either a string or an integer', E_USER_WARNING);
            return false;
        }

        if (isset($params[2])
            && !is_int($params[2])
            && !is_float($params[2])
            && !is_string($params[2])
            && !(is_object($params[2]) && method_exists($params[2], '__toString'))
        ) {
            trigger_error('array_column(): The index key should be either a string or an integer', E_USER_WARNING);
            return false;
        }

        $paramsInput = $params[0];
        $paramsColumnKey = ($params[1] !== null) ? (string) $params[1] : null;

        $paramsIndexKey = null;
        if (isset($params[2])) {
            if (is_float($params[2]) || is_int($params[2])) {
                $paramsIndexKey = (int) $params[2];
            } else {
                $paramsIndexKey = (string) $params[2];
            }
        }

        $resultArray = array();

        foreach ($paramsInput as $row) {

            $key = $value = null;
            $keySet = $valueSet = false;

            if ($paramsIndexKey !== null && array_key_exists($paramsIndexKey, $row)) {
                $keySet = true;
                $key = (string) $row[$paramsIndexKey];
            }

            if ($paramsColumnKey === null) {
                $valueSet = true;
                $value = $row;
            } elseif (is_array($row) && array_key_exists($paramsColumnKey, $row)) {
                $valueSet = true;
                $value = $row[$paramsColumnKey];
            }

            if ($valueSet) {
                if ($keySet) {
                    $resultArray[$key] = $value;
                } else {
                    $resultArray[] = $value;
                }
            }

        }

        return $resultArray;
    }

}


if (!class_exists('pulse_options_config')) {

    class pulse_options_config {

        public $args        = array();
        public $sections    = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if (1) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }
        }

        public function initSettings() {
            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            //$this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            //add_action( 'redux/loaded', array( $this, 'remove_demo' ) );

            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array( $this, 'compiler_action' ), 10, 2);

            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );

            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );

            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**


        /**

        Custom function for filtering the sections array. Good for child themes to override or add to the sections.
        Simply include this function in the child themes functions.php file.

        NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
        so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array();
            $sections[] = array(
                'title' => __('Section via hook', 'pulse'),
                'desc' => __('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'pulse'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }

        /**

        Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

         * */
        function change_arguments($args) {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**

        Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo() {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {
            //Background Patterns Reader
            $sample_patterns_path = get_theme_file_path('images/patterns');
            $sample_patterns_url  = get_template_directory_uri() . '/images/patterns/';
            $sample_patterns      = array();
            if ( is_dir( $sample_patterns_path ) ) {
                if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) :
                    $sample_patterns = array();
                    $sample_patterns[] = array( 'alt'=>'none','img' => $sample_patterns_url .'empty/prk_no_pattern.jpg' );
                    while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {
                        if( (stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false) &&  stristr( $sample_patterns_file, '_@2X')===false) {
                            $name = explode(".", $sample_patterns_file);
                            $name = str_replace('.'.end($name), '', $sample_patterns_file);
                            $sample_patterns[] = array( 'alt'=>$name,'img' => $sample_patterns_url . $sample_patterns_file );
                        }
                    }
                endif;
            }


            $prk_select_font_options=pulse_fonts();
            $a = array_column($prk_select_font_options, 'value');
            $b = array_column($prk_select_font_options, 'label');
            $fonts_array=array_combine($a, $b);
            $prk_font_options = get_option('prk_font_plugin_option');
            if (is_array($prk_font_options)) {
                foreach ($prk_font_options as $font)
                {
                    if ($font['erased']=="false" && !array_key_exists($font['value'],$fonts_array))
                    {
                        $fonts_array[$font['value']] = $font['label'];
                    }
                }
            }
            $social_options=array(
                'delicious' => 'Delicious',
                'deviantart' => 'Deviantart',
                'dribbble' => 'Dribbble',
                'facebook-official' => 'Facebook',
                'flickr' => 'Flickr',
                'gplus' => 'Google Plus',
                'instagram' => 'Instagram',
                'linkedin-square' => 'Linkedin',
                'medium' => 'Medium',
                'pinterest' => 'Pinterest',
                'skype' => 'Skype',
                'soundcloud' => 'Soundcloud',
                'twitter' => 'Twitter',
                'vimeo' => 'Vimeo',
                'vk' => 'VK',
                'youtube' => 'Youtube',
                'rss' => 'RSS'
            );

            ob_start();

            $ct             = wp_get_theme();
            $this->theme    = $ct;
            $item_name      = $this->theme->get('Name');
            $tags           = $this->theme->Tags;
            $screenshot     = $this->theme->get_screenshot();
            $class          = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'pulse'), $this->theme->display('Name'));

            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
                <?php if ($screenshot) : ?>
                    <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview','pulse'); ?>" />
                        </a>
                    <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview','pulse'); ?>" />
                <?php endif; ?>

                <h4><?php echo esc_attr($this->theme->display('Name')); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', 'pulse'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', 'pulse'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . __('Tags', 'pulse') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo esc_attr($this->theme->display('Description')); ?></p>
                    <?php
                    if ($this->theme->parent()) {
                        printf(' <p class="howto">' . __('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.', 'pulse') . '</p>', __('http://codex.wordpress.org/Child_Themes', 'pulse'), $this->theme->parent()->display('Name'));
                    }
                    ?>

                </div>
            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();
            $align_array=array(
                'pulse_left_align' => __('Left', 'pulse'),
                'pulse_center_align' => __('Centred', 'pulse'),
                'pulse_right_align' => __('Right', 'pulse'),
            );

            $sampleHTML = '';
            if (false) {
                /** @global WP_Filesystem_Direct $wp_filesystem  */
                global $wp_filesystem;
                if (empty($wp_filesystem)) {
                    require_once(ABSPATH . '/wp-admin/includes/file.php');
                    WP_Filesystem();
                }
                $sampleHTML = $wp_filesystem->get_contents('/info-html.html');
            }

            // ACTUAL DECLARATION OF SECTIONS
            $this->sections[] = array(
                'title'     => __('General', 'pulse'),
                'desc'      => __('', 'pulse'),
                'icon'      => 'el-icon-cogs',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                    array(
                        'id'=>'pulse_responsive',
                        'type' => 'switch',
                        'title' => __('Make the theme layout responsive?', 'pulse'),
                        'subtitle'=> __('Make theme adjust to smaller screens.', 'pulse'),
                        "default"       => 1,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'pulse_detect_retina',
                        'type' => 'switch',
                        'title' => __('Detect and serve better images on retina screens?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'show_sooner',
                        'type' => 'select',
                        'title' => __('Show content before all images are loaded?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'no' => 'No',
                            'yes' => 'Yes',
                        ),
                        'default' => array('no' => 'No'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'custom_width',
                        'type' => 'text',
                        'title' => __('Maximum content width', 'pulse'),
                        'subtitle' => __('Numeric values only.', 'pulse'),
                        'desc' => __('How much the center content will stretch. Not applicable on some pages.', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '1280',
                        'class' => 'small-text',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'ajax_calls',
                        'type' => 'switch',
                        'title' => __('Use Ajax calls to load content?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        'desc' => __('If on the theme will attempt to load all content using Ajax calls. This will speed up the website page loading process and allow some elements to have smoother transitions.', 'pulse'),
                        "default"       => 0,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'smooth_scroll',
                        'type' => 'switch',
                        'title' => __('Smooth mouse wheel scrolling on Chrome?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        "default"       => 0,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'backend_fonts',
                        'type' => 'info',
                        'desc' => __('Fonts', 'pulse')
                    ),
                    array(
                        'id'=>'font_size',
                        'type' => 'slider',
                        'title' => __('Body font size', 'pulse'),
                        'subtitle'=> __('Important: all other font sizes are calculated according to this value.', 'pulse'),
                        'desc'=> __('Min: 5, max: 30', 'pulse'),
                        "default"       => "15",
                        "min"       => "5",
                        "step"      => "1",
                        "max"       => "30",
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'header_font',
                        'type' => 'select',
                        'class' => 'prk_hide_default',
                        'title' => __('Headings font', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $fonts_array,//Must provide key => value pairs for select options
                        'default' => array(
                            'value' => 'Open+Sans:300italic,400italic,400,300,700,600,800',
                            'css' => 'Open Sans',
                            'hosted'=> 'google'
                        ),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'uppercase_headings',
                        'type' => 'switch',
                        'title' => __('Uppercase text that uses the headings font?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 0,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'body_font',
                        'type' => 'select',
                        'title' => __('Body font', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $fonts_array,//Must provide key => value pairs for select options
                        'default' => array(
                            'value' => 'PT+Sans:400,700,400italic,700italic',
                            'css' => "'PT Sans', sans-serif",
                            'hosted'=> 'google'
                        ),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'custom_font',
                        'type' => 'select',
                        'title' => __('Extra font', 'pulse'),
                        'subtitle' => __('Optional', 'pulse'),
                        'desc' => __('To apply this font to certain elements simply add the CSS class <strong>extra_font</strong>', 'pulse'),
                        'options' => $fonts_array,//Must provide key => value pairs for select options
                        'default' => array(
                            'value' => '',
                            'css' => '',
                            'hosted'=> ''
                        ),
                        'compiler' => 'true'
                    ),
                    array('id'=>'custom_font_style',
                        'type' => 'select',
                        'title' => __('Extra font default style', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'normal' => __('Normal','pulse'),
                            'italic' => __('Italic','pulse')),
                        'default' => 'italic',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'titles_font',
                        'type' => 'select',
                        'title' => __('Pages and single posts title font face', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('Default value is Headings font', 'pulse'),
                        'options' => array(
                            'header_font' => __('Headings font', 'pulse'),
                            'body_font' => __('Body font', 'pulse'),
                            'custom_font' => __('Extra font', 'pulse')),
                        'default' => 'header_font',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'main_subheadings_font',
                        'type' => 'select',
                        'title' => __('Pages and single posts sub-headings font face', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('Default value is Headings font', 'pulse'),
                        'options' => array(
                            'header_font' => __('Headings font', 'pulse'),
                            'body_font' => __('Body font', 'pulse'),
                            'custom_font' => __('Extra font', 'pulse')),
                        'default' => 'body_font',
                        'compiler' => 'true'
                    ),
                    array('id'=>'subheadings_style',
                        'type' => 'select',
                        'title' => __('Pages and single posts sub-headings font style', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'normal' => __('Normal','pulse'),
                            'italic' => __('Italic','pulse')),
                        'default' => 'italic',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'headings_align',
                        'type' => 'select',
                        'title' => __('Default pages and single posts title and sub-heading text alignment', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'pulse_left_align' => __('Left', 'pulse'),
                            'pulse_center_align' => __('Centred', 'pulse'),
                            'pulse_right_align' => __('Right', 'pulse')),
                        'default' => 'pulse_center_align',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'drop_caps_size',
                        'type' => 'slider',
                        'title' => __('Drop caps size font size (in pixels)', 'pulse'),
                        'desc'=> __('Min: 8, max: 150', 'pulse'),
                        "default"       => "52",
                        "min"       => "8",
                        "step"      => "1",
                        "max"       => "150",
                    ),
                    array(
                        'id'=>'backend_gn_colors',
                        'type' => 'info',
                        'desc' => __('Colors: General', 'pulse')
                    ),
                    array(
                        'id'=>'use_custom_colors',
                        'type' => 'switch',
                        'title' => __('Use special colors for single posts and portfolio entries?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        "default"       => 1,
                        'compiler' => 'true'
                    ),
                    /*array(
                        'id'=>'boxed_image',
                        'type' => 'media',
                        'title' => __('Background image', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>'',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('Optional', 'pulse'),
                        'subtitle' => __('Only for boxed layouts.', 'pulse'),
                        'required' => array('layout','equals','boxed_pulse'),
                        'compiler' => 'true'
                        ),*/
                    array('id'=>'site_background_color',
                        'type' => 'color',
                        'title' => __('Site background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'pattern',
                        'type' => 'image_select',
                        'tiles' => true,
                        'title' => __('Site background pattern image', 'pulse'),
                        'subtitle'=> __('Optional', 'pulse'),
                        'desc'=> __('To add more images place them inside wp-content/themes/pulse/images/patterns/', 'pulse'),
                        'default'       => '',
                        'options' => $sample_patterns,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'active_color',
                        'type' => 'color',
                        'title' => __('Theme active color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#49B6B2',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'bd_headings_color',
                        'type' => 'color',
                        'title' => __('Text headings color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#27394A',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'bd_smallers_color',
                        'type' => 'color',
                        'title' => __('Text small headings color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#485767',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'inactive_color',
                        'type' => 'color',
                        'title' => __('Body text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#9BABB3',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'thumbs_text_color_blog',
                        'type' => 'color',
                        'title' => __('Thumbnails text color - Blog', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'background_color_btns_blog',
                        'type' => 'color',
                        'title' => __('Thumbnails rollover color - Blog (default value)', 'pulse'),
                        'subtitle' => __('Posts with a featured color will override this option', 'pulse'),
                        'default' => '#111111',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'custom_opacity',
                        'type' => 'slider',
                        'title' => __('Custom Background Opacity - Blog rollover effects', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "60",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'thumbs_text_color',
                        'type' => 'color',
                        'title' => __('Thumbnails text color - Portfolio', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'background_color_btns',
                        'type' => 'color',
                        'title' => __('Thumbnails rollover color - Portfolio (default value)', 'pulse'),
                        'subtitle' => __('Posts with a featured color will override this option', 'pulse'),
                        'default' => '#111111',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'custom_opacity_folio',
                        'type' => 'slider',
                        'title' => __('Custom Background Opacity - Portfolio rollover effects', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "85",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'backend_lb_colors',
                        'type' => 'info',
                        'desc' => __('Colors: Textfields, lines and borders', 'pulse')
                    ),
                    array(
                        'id'=>'lines_color', 'type' => 'color',
                        'title' => __('Lines color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#E7EEF0',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    /*array(
                        'id'=>'shadow_color', 'type' => 'color',
                        'title' => __('Shadow color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#111111',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'custom_shadow',
                        'type' => 'slider',
                        'title' => __('Shadow opacity', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "30",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                        'compiler' => 'true'
                    ),*/
                    array(
                        'id'=>'background_color',
                        'type' => 'color',
                        'title' => __('Textfields background color', 'pulse'),
                        'subtitle' => __('Will also be used on other elements (Ex: pricing tables, progress bars, etc)', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'inputs_bordercolor',
                        'type' => 'color',
                        'title' => __('Textfields border color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#E7EEF0',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'backend_btn_colors',
                        'type' => 'info',
                        'desc' => __('Colors and styling: Buttons', 'pulse')
                    ),
                    /*array(
                        'id'=>'buttons_style',
                        'type' => 'select',
                        'title' => __('Buttons general style?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array('solid_buttons' => __('Always solid colors', 'pulse'),'bordered_buttons' => __('Bordered if mouse is not over', 'pulse')),
                        'default' => 'bordered_buttons',
                        'compiler' => 'true'
                    ),*/
                    array(
                        'id'=>'buttons_font',
                        'type' => 'select',
                        'title' => __('Buttons font', 'pulse'),
                        'subtitle' => __('Select the font face to be used for the theme buttons.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'headings_f' => __('Headings font', 'pulse'),
                            'body_f' => __('Body font', 'pulse'),
                            'custom_f' => __('Extra font', 'pulse')),
                        'default' => 'headings_f',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'uppercase_buttons',
                        'type' => 'switch',
                        'title' => __('Uppercase text on buttons?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'buttons_border',
                        'type' => 'slider',
                        'title' => __('Ghost buttons border width', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc'=> __('Min: 1, max: 5', 'pulse'),
                        "default"       => "1",
                        "min"       => "0",
                        "step"      => "1",
                        "max"       => "5",
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'buttons_radius',
                        'type' => 'slider',
                        'title' => __('Buttons border radius', 'pulse'),
                        'subtitle' => __('Use 0 for squared buttons', 'pulse'),
                        'desc'=> __('Min: 0, max: 40', 'pulse'),
                        "default"       => "0",
                        "min"       => "0",
                        "step"      => "1",
                        "max"       => "100",
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'buttons_text_color',
                        'type' => 'color',
                        'title' => __('Buttons text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#FFFFFF', '
                validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'theme_buttons_color',
                        'type' => 'color',
                        'title' => __('Buttons background color', 'pulse'),
                        'subtitle' => __('The alternative background color will be the theme current active color', 'pulse'),
                        'default' => '#27394A',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'buttons_inner_shadow',
                        'type' => 'switch',
                        'title' => __('Apply inner shadow on buttons?', 'pulse'),
                        'subtitle'=> __('Will be placed on the lower part of the button.', 'pulse'),
                        "default"       => 0,
                        /*'required' => array('buttons_style','equals','solid_buttons'), */
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'slider_text_color',
                        'type' => 'color',
                        'title' => __('Slider, team members and navigation buttons text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#FFFFFF', '
                validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'buttons_color',
                        'type' => 'color',
                        'title' => __('Slider, team members and navigation buttons background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#27252C', '
                validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'back_to_top_bk',
                        'type' => 'color',
                        'title' => __('Back to top button background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#212427', '
                validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array( 'id'=>'back_to_top_color',
                        'type' => 'color',
                        'title' => __('Back to top button color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#FFFFFF', '
                validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'filters_bk_color',
                        'type' => 'color',
                        'title' => __('Filter buttons background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#F0F0F0',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'backend_gn_colors_oth',
                        'type' => 'info',
                        'desc' => __('Colors: Other', 'pulse')
                    ),
                    array(
                        'id'=>'preloader_style',
                        'type' => 'select',
                        'title' => __('Preloader style', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'theme_default' => __('Animated bars', 'pulse'),
                            'theme_circles' => __('Animated circles', 'pulse'),
                            'custom_image' => __('Custom image', 'pulse')),
                        'default' => 'theme_circles',
                        'compiler' => 'true',
                    ),
                    array(
                        'id'=>'preloader_color',
                        'type' => 'color',
                        'title' => __('Preloader color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#49B6B2',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('preloader_style','not','custom_image'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'preloader_image',
                        'type' => 'media',
                        'title' => __('Preloader image', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>'',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('', 'pulse'),
                        'subtitle' => __('Maximum recommended dimensions: 200x200 pixels', 'pulse'),
                        'required' => array('preloader_style','equals','custom_image'),
                    ),
                    array(
                        'id'=>'preloader_image_retina',
                        'type' => 'media',
                        'title' => __('Preloader image for retina screens', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>'',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('', 'pulse'),
                        'subtitle' => __('Optional - If used should be the double size of the original preloader image.', 'pulse'),
                        'required' => array('preloader_style','equals','custom_image'),
                    ),
                    array(
                        'id'=>'background_color_dots',
                        'type' => 'color',
                        'title' => __('Navigation rectangles up color', 'pulse'),
                        'subtitle' => __('Will be used only if navigation using fixed-position rectangles is active for a page', 'pulse'),
                        'default' => '#FFFFFF',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'featured_header_color',
                        'type' => 'color',
                        'title' => __('Featured header text color', 'pulse'),
                        'subtitle' => __('Will be used on posts and portfolio items with featured media', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    /*array(
                        'id'=>'featured_slider_bk_color',
                        'type' => 'color',
                        'title' => __('Featured header background color', 'pulse'),
                        'subtitle' => __('Will be visible only while featured media is loading', 'pulse'),
                        'default' => '#dddddd',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                        ),*/
                    /*array(
                        'id'=>'tips_text_color',
                        'type' => 'color',
                        'title' => __('Tooltips text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                        ),
                    array(
                        'id'=>'tips_background_color',
                        'type' => 'color',
                        'title' => __('Tooltips background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#111111',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                        ),
                    array(
                        'id'=>'tips_background_opacity',
                        'type' => 'slider',
                        'title' => __('Tooltips background opacity', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "100",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                        'compiler' => 'true'
                        ),
                    array(
                        'id'=>'members_social_colors',
                        'type' => 'color',
                        'title' => __('Team members social networks color', 'pulse'),
                        'subtitle' => __('Will be used only on icons displayed inside member thumbnails', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                        ),*/
                    array(
                        'id'=>'bk_color_sidebar_overlay',
                        'type' => 'color',
                        'title' => __('Content overlay background color', 'pulse'),
                        'subtitle' => __('Will be shown when: the mobile sidebar is visible or the menu search overlay is active.', 'pulse'),
                        'default' => '#111111',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'backend_sdb_sidebars',
                        'type' => 'info',
                        'desc' => __('Sidebars', 'pulse')
                    ),
                    array(
                        'id'=>'right_sidebar',
                        'type' => 'switch',
                        'title' => __('Display right sidebar on pages and posts by default?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,//WAS
                        'compiler' => 'true'
                    ),
                ));
            $this->sections[] = array(
                'icon' => 'el-icon-star',
                'title' => __('Branding', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'logo_align',
                        'type' => 'select',
                        'title' => __('Logo position?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'st_logo_on_left' => __('Left', 'pulse'),
                            'st_logo_on_right' => __('Right', 'pulse')),
                        'default' => 'st_logo_on_left',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'logo',
                        'type' => 'media',
                        'title' => __('Logo', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>get_template_directory_uri().'/images/logo.png',
                            'id'=>'',
                            'width'=>'160',
                            'height'=>'',
                        ),
                        'desc'=> __('', 'pulse'),
                        'subtitle' => __('Optional - Leave blank if logo is not needed.', 'pulse'),
                    ),
                    array(
                        'id'=>'logo_retina',
                        'type' => 'media',
                        'title' => __('Logo for retina screens', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>get_template_directory_uri().'/images/logo-retina.png',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('', 'pulse'),
                        'subtitle' => __('Optional - If used should be the double size of the original logo image.', 'pulse'),
                    ),
                    array( 'id'=>'logo_top_margin',
                        'type' => 'text',
                        'title' => __('Logo top margin', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '39',
                        'class' => 'small-text',
                    ),
                    array(
                        'id'=>'logo_collapsed',
                        'type' => 'media',
                        'title' => __('Logo - After scroll & forced menu pages', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>get_template_directory_uri().'/images/persistent-regular.png',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('', 'pulse'),
                        'subtitle' => __('Options - Leave blank if logo is not needed or if the persistent menu is off.', 'pulse'),
                    ),
                    array(
                        'id'=>'logo_collapsed_retina',
                        'type' => 'media',
                        'title' => __('Logo retina screens - After scroll & forced menu pages', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>get_template_directory_uri().'/images/persistent-retina.png',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('', 'pulse'),
                        'subtitle' => __('Optional - If used should be the double size of the original logo image.', 'pulse'),
                    ),
                    array( 'id'=>'logo_collapsed_top_margin',
                        'type' => 'text',
                        'title' => __('Logo top margin - After scroll', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '16',
                        'class' => 'small-text',
                    ),
                    array(
                        'id'=>'favicon',
                        'type' => 'media',
                        'title' => __('Favicon image', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>get_template_directory_uri().'/images/favicon.ico',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('Should have .ico as file extension.', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-list',
                'title' => __('Header Section', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'top_bar_limited_width',
                        'type' => 'switch',
                        'title' => __('Make header bar elements align with content?', 'pulse'),
                        'subtitle'=> __('If NO they will stretch until the window width.', 'pulse'),
                        "default"       => 0,
                    ),
                    array(
                        'id'=>'resp_break',
                        'type' => 'text',
                        'title' => __('Minimum window width before activate mobile mode', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('Mobile mode will always be activated on screens with less than 768px.', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '900',
                        'class' => 'small-text'
                    ),
                    array( 'id'=>'menu_vertical',
                        'type' => 'text',
                        'title' => __('Header bar height', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '120',
                        'class' => 'small-text',
                    ),
                    array(
                        'id'=>'background_color_menu_bar',
                        'type' => 'color',
                        'title' => __('Header bar background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#212427',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'border_menu_bar',
                        'type' => 'color',
                        'title' => __('Header bar lower border color', 'pulse'),
                        'subtitle' => __('Optional', 'pulse'),
                        'default' => '#272930',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'header_default_opacity',
                        'type' => 'slider',
                        'title' => __('Header bar background opacity', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "0",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                    ),
                    array(
                        'id'=>'menu_align',
                        'type' => 'select',
                        'title' => __('Menu position?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'st_menu_on_left' => __('Left', 'pulse'),
                            'st_menu_on_right' => __('Right', 'pulse'),
                            'st_menu_under' => __('Under Logo', 'pulse'),
                        ),
                        'default' => 'st_menu_on_right',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'menu_display',
                        'type' => 'select',
                        'title' => __('Header bar menu display?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'st_regular_menu' => __('Regular', 'pulse'),
                            'st_hidden_menu' => __('Hidden - "Hamburger" Menu button', 'pulse'),
                            'st_without_menu' => __('Do not display any menu', 'pulse'),
                        ),
                        'default' => 'st_regular_menu',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'menu_hide_flag',
                        'type' => 'switch',
                        'title' => __('Menu hides after scrolling?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 0,
                    ),
                    array( 'id'=>'menu_hide_pixels',
                        'type' => 'text',
                        'title' => __('How many pixels before hiding menu?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '160',
                        'class' => 'small-text',
                        'required' => array('menu_hide_flag','equals','1')
                    ),
                    array(
                        'id'=>'bk_color_menu_overlay',
                        'type' => 'color',
                        'title' => __('Menu overlay background color', 'pulse'),
                        'subtitle' => __('Will be shown when the hidden menu is visible', 'pulse'),
                        'default' => '#333038',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('menu_display','equals','st_hidden_menu'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'opacity_menu_overlay',
                        'type' => 'slider',
                        'title' => __('Menu overlay opacity', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "97",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                        'required' => array('menu_display','equals','st_hidden_menu'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'active_color_menu_overlay',
                        'type' => 'color',
                        'title' => __('Menu overlay active color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#000000',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('menu_display','equals','st_hidden_menu'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'color_menu_overlay',
                        'type' => 'color',
                        'title' => __('Menu overlay up color color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#000000',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('menu_display','equals','st_hidden_menu'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'overlay_align',
                        'type' => 'select',
                        'title' => __('Menu overlay text alignment?', 'pulse'),
                        'subtitle' => __('Default value is centred.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $align_array,
                        'required' => array('menu_display','equals','st_hidden_menu'),
                        'default' => 'pulse_center_align',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'overlay_page_id',
                        'type' => 'select',
                        'data' => 'pages',
                        'title' => __('Append page to Menu Overlay?', 'pulse'),
                        'subtitle' => __('If empty the theme Main Menu will be displayed.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        "default"       => '',
                        'required' => array('menu_display','equals','st_hidden_menu'),
                    ),
                    array(
                        'id'=>'overlay_footer_text',
                        'type' => 'editor',
                        'title' => __('Overlay footer text', 'pulse'),
                        'subtitle' => __('Space is limited so use very few text.', 'pulse'),
                        'default' => __('','pulse'),
                        'editor_options'   => array(
                            'teeny'            => true,
                            'textarea_rows'    => 1,
                            'media_buttons'    => false,
                            'tinymce'          => false
                        ),
                        'required' => array('menu_display','equals','st_hidden_menu'),
                    ),
                    array(
                        'id'=>'backend_widgets_mainmenu_buttons',
                        'type' => 'info',
                        'desc' => __('Main menu: parent buttons style', 'pulse')
                    ),
                    array('id'=>'menu_padding',
                        'type' => 'slider',
                        'title' => __('Parent menu buttons horizontal padding (in pixels)', 'pulse'),
                        'desc'=> __('Min: 4, max: 20', 'pulse'),
                        "default"   => "14",
                        "min"       => "2",
                        "step"      => "1",
                        "max"       => "50",
                    ),
                    array(
                        'id'=>'menu_font',
                        'type' => 'select',
                        'title' => __('Menu buttons font face', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('Default value is Headings font', 'pulse'),
                        'options' => array(
                            'header_font' => __('Headings font', 'pulse'),
                            'body_font' => __('Body font', 'pulse'),
                            'custom_font' => __('Extra font', 'pulse')),
                        'default' => 'header_font',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'menu_font_size',
                        'type' => 'slider',
                        'title' => __('Parent menu buttons font size (in pixels)', 'pulse'),
                        'desc'=> __('Min: 8, max: 50', 'pulse'),
                        "default"       => "16",
                        "min"       => "8",
                        "step"      => "1",
                        "max"       => "50",
                    ),
                    array(
                        'id'=>'menu_parent_style',
                        'type' => 'select',
                        'title' => __('Parent menu buttons font style?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array('normal' => __('Normal','pulse'),'italic' => __('Italic','pulse')),
                        'default' => 'normal',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'menu_font_weight',
                        'type' => 'select',
                        'title' => __('Parent menu buttons font weight?', 'pulse'),
                        'subtitle' => __('Fonts usually support only certain sizes.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            '100' => '100',
                            '200' => '200',
                            '300' => '300',
                            '400' => __('Normal','pulse'),
                            '500' => '500',
                            '600' => '600',
                            '700' => __('Bold','pulse'),
                            '900' => __('Bolder','pulse')
                        ),
                        'default' => '600',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'labels_offset',
                        'type' => 'text',
                        'title' => __('Parent menu buttons top offset', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('Useful to postion text vertically.', 'pulse'),
                        "default"       => '0',
                    ),
                    array( 'id'=>'menu_active_color',
                        'type' => 'color',
                        'title' => __('Parent menu buttons active text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#49B6B2',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array( 'id'=>'menu_up_color',
                        'type' => 'color',
                        'title' => __('Parent menu buttons text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#FFFFFF',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array('id'=>'active_subheadings',
                        'type' => 'switch',
                        'title' => __('Append sub-headings to parent menu buttons?', 'pulse'),
                        'subtitle'=> __('Text is set under Appearance>Menus and it is the Title Attribute', 'pulse'),
                        "default"       => 0,
                    ),
                    array('id'=>'menu_subheadings_style',
                        'type' => 'select',
                        'title' => __('Sub-headings menu buttons font style?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'normal' => __('Normal','pulse'),
                            'italic' => __('Italic','pulse')),
                        'default' => 'italic',
                        'compiler' => 'true',
                        'required' => array('active_subheadings','equals','1'),
                    ),
                    array('id'=>'subheadings_font_weight',
                        'type' => 'select',
                        'title' => __('Sub-headings buttons font weight?', 'pulse'),
                        'subtitle' => __('Fonts usually support only certain sizes.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array('100' => '100','200' => '200','300' => '300','400' => __('Normal','pulse'),'500' => '500','600' => '600','700' => __('Bold','pulse'),'900' => __('Bolder','pulse')),
                        'default' => '400',
                        'compiler' => 'true',
                        'required' => array('active_subheadings','equals','1'),
                    ),
                    array('id'=>'subheadings_color',
                        'type' => 'color',
                        'title' => __('Sub-headings text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#a8a8a8',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('active_subheadings','equals','1'),
                    ),
                    array('id'=>'subheadings_font_size',
                        'type' => 'slider',
                        'title' => __('Sub-headings font size (in pixels)', 'pulse'),
                        'desc'=> __('Min: 4, max: 20', 'pulse'),
                        "default"       => "10",
                        "min"       => "8",
                        "step"      => "1",
                        "max"       => "20",
                        'required' => array('active_subheadings','equals','1'),
                    ),
                    array('id'=>'subheadings_offset',
                        'type' => 'text',
                        'title' => __('Sub-headings top offset', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('Useful to postion text vertically.', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '36',
                        'class' => 'small-text',
                        'required' => array('active_subheadings','equals','1'),
                    ),
                    array('id'=>'subheadings_font',
                        'type' => 'select',
                        'title' => __('Sub-headings font face', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('Default value is Headings font', 'pulse'),
                        'options' => array(
                            'header_font' => __('Headings font', 'pulse'),
                            'body_font' => __('Body font', 'pulse'),
                            'custom_font' => __('Extra font', 'pulse')),
                        'default' => 'custom_font',
                        'compiler' => 'true',
                        'required' => array('active_subheadings','equals','1'),
                    ),
                    array('id'=>'backend_widgets_submenu_buttons',
                        'type' => 'info',
                        'desc' => __('Main menu: sub-menu buttons style', 'pulse')
                    ),
                    array('id'=>'submenu_font_size',
                        'type' => 'slider',
                        'title' => __('Sub-menu buttons font size (in pixels)', 'pulse'),
                        'desc'=> __('Min: 8, max: 50', 'pulse'),
                        "default"       => "12",
                        "min"       => "8",
                        "step"      => "1",
                        "max"       => "50",
                    ),
                    array(
                        'id'=>'submenu_font_weight',
                        'type' => 'select',
                        'title' => __('Sub-menu buttons font weight?', 'pulse'),
                        'subtitle' => __('Fonts usually support only certain sizes.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array('100' => '100','200' => '200','300' => '300','400' => __('Normal','pulse'),'500' => '500','600' => '600','700' => __('Bold','pulse'),'900' => __('Bolder','pulse')),
                        'default' => '400',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'menu_sub_padding',
                        'type' => 'slider',
                        'title' => __('Sub-menu buttons height (in pixels)', 'pulse'),
                        'desc'=> __('Min: 8, max: 60', 'pulse'),
                        "default"       => "36",
                        "min"       => "0",
                        "step"      => "1",
                        "max"       => "60",
                    ),
                    array( 'id'=>'submenu_active_color',
                        'type' => 'color',
                        'title' => __('Sub-menu buttons active text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#49B6B2',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array( 'id'=>'submenu_text_color',
                        'type' => 'color',
                        'title' => __('Sub-menu buttons text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#FFFFFF',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'submenu_lines_color',
                        'type' => 'color',
                        'title' => __('Sub-menu divider lines color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#272930',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'submenu_background_color',
                        'type' => 'color',
                        'title' => __('Submenu background color', 'pulse'),
                        'subtitle' => __('Pick a background color for the sub-menus.', 'pulse'),
                        'default' => '#212427',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'backend_widgets_mirror_menu',
                        'type' => 'info',
                        'desc' => __('Main menu: after scroll style, forced menu pages & mobile mode.', 'pulse')
                    ),
                    array( 'id'=>'menu_collapse_flag',
                        'type' => 'switch',
                        'title' => __('Menu changes style after scrolling?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array('id'=>'menu_collapse_pixels',
                        'type' => 'text',
                        'title' => __('How many pixels before changing style', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        "default"       => '200',
                        'required' => array('menu_collapse_flag','equals','1'),
                    ),
                    array('id'=>'collapsed_menu_vertical',
                        'type' => 'text',
                        'title' => __('Menu height - after scroll', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('Use the same value as the menu height (option above) to disable the menu collapse effect.', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '72',
                        'class' => 'small-text',
                        'required' => array('menu_collapse_flag','equals','1')
                    ),
                    array(
                        'id'=>'header_opacity_after',
                        'type' => 'slider',
                        'title' => __('Menu background opacity - after scroll', 'pulse'),
                        'subtitle' => __('After scroll, forced menu pages & mobile mode.', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "98",
                        "min"       => "0",
                        "step"      => "1",
                        "max"       => "100",
                    ),
                    array( 'id'=>'menu_active_color_after',
                        'type' => 'color',
                        'title' => __('Menu active text color- after scroll', 'pulse'),
                        'subtitle' => __('After scroll, forced menu pages & mobile mode.', 'pulse'),
                        'default' => '#49B6B2',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array( 'id'=>'menu_up_color_after',
                        'type' => 'color',
                        'title' => __('Menu text color- after scroll', 'pulse'),
                        'subtitle' => __('After scroll, forced menu pages & mobile mode.', 'pulse'),
                        'default' => '#FFFFFF',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'backend_widgets_top_bar',
                        'type' => 'info',
                        'desc' => __('Social networks links', 'pulse')
                    ),
                    array(
                        'id'=>'network_icon_1',
                        'type' => 'select',
                        'title' => __('Social Network 1', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $social_options,//Must provide key => value pairs for select options
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => ""
                    ),
                    array(
                        'id'=>'network_link_1',
                        'type' => 'text',
                        'title' => __('Social Network 1 Link', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => "",
                        //'required' => array('show_top_bar','equals','1'),
                    ),
                    array(
                        'id'=>'network_icon_2',
                        'type' => 'select',
                        'title' => __('Social Network 2', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $social_options,//Must provide key => value pairs for select options
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => ""
                    ),
                    array(
                        'id'=>'network_link_2',
                        'type' => 'text',
                        'title' => __('Social Network 2 Link', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => "",
                        //'required' => array('show_top_bar','equals','1'),
                    ),
                    array(
                        'id'=>'network_icon_3',
                        'type' => 'select',
                        'title' => __('Social Network 3', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $social_options,//Must provide key => value pairs for select options
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => ""
                    ),
                    array(
                        'id'=>'network_link_3',
                        'type' => 'text',
                        'title' => __('Social Network 3 Link', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => "",
                        //'required' => array('show_top_bar','equals','1'),
                    ),
                    array(
                        'id'=>'network_icon_4',
                        'type' => 'select',
                        'title' => __('Social Network 4', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $social_options,//Must provide key => value pairs for select options
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => ""
                    ),
                    array(
                        'id'=>'network_link_4',
                        'type' => 'text',
                        'title' => __('Social Network 4 Link', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => "",
                        //'required' => array('show_top_bar','equals','1'),
                    ),
                    array(
                        'id'=>'network_icon_5',
                        'type' => 'select',
                        'title' => __('Social Network 5', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $social_options,//Must provide key => value pairs for select options
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => ""
                    ),
                    array(
                        'id'=>'network_link_5',
                        'type' => 'text',
                        'title' => __('Social Network 5 Link', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => "",
                    ),
                    array(
                        'id'=>'network_icon_6',
                        'type' => 'select',
                        'title' => __('Social Network 6', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $social_options,//Must provide key => value pairs for select options
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => ""
                    ),
                    array(
                        'id'=>'network_link_6',
                        'type' => 'text',
                        'title' => __('Social Network 6 Link', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        //'required' => array('show_top_bar','equals','1'),
                        'default' => "",
                    ),
                    array(
                        'id'=>'nets_offset',
                        'type' => 'text',
                        'title' => __('Social networks links top offset', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('Useful to adjust links vertical position.', 'pulse'),
                        "default"       => '-14',
                    ),
                    array(
                        'id'=>'top_search',
                        'type' => 'switch',
                        'title' => __('Append search icon to menu?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-website',
                'title' => __('Mobile Mode', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'backend_sdb_mobile',
                        'type' => 'info',
                        'desc' => __('Mobile mode features', 'pulse')
                    ),
                    array(
                        'id'=>'menu_on_mobile',
                        'type' => 'switch',
                        'title' => __('Show top menu bar on mobile devices?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'css_enable',
                        'type' => 'switch',
                        'title' => __('Enable CSS animations for page elements on mobile devices?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 0,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'backend_sdb_mobile_menu',
                        'type' => 'info',
                        'desc' => __('Mobile Bar', 'pulse')
                    ),
                    array(
                        'id'=>'append_mobile_logo',
                        'type' => 'select',
                        'title' => __('Show logo on mobile bar?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'no' => __('No', 'pulse'),
                            'mobile_logo_bef' => __('Yes, logo before scroll', 'pulse'),
                            'mobile_logo_aft' => __('Yes, logo after scroll', 'pulse')
                        ),
                        'default' => 'mobile_logo_aft',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'right_bar_align',
                        'type' => 'select',
                        'title' => __('Mobile menu bar text alignment?', 'pulse'),
                        'subtitle' => __('Default value is centred.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $align_array,
                        'default' => 'pulse_left_align',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'background_image_right_bar',
                        'type' => 'media',
                        'title' => __('Mobile menu bar background image', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>'',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('Optional', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                    ),
                    array(
                        'id'=>'background_color_right_bar',
                        'type' => 'color',
                        'title' => __('Mobile menu bar background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#111111',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'active_color_right_bar',
                        'type' => 'color',
                        'title' => __('Mobile menu bar active text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'body_color_right_bar',
                        'type' => 'color',
                        'title' => __('Mobile menu bar text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#969696',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'opacity_mobile_overlay',
                        'type' => 'slider',
                        'title' => __('Content overlay opacity', 'pulse'),
                        'subtitle' => __('Applicable only for when the hidden sidebar is visible.', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "75",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                        'compiler' => 'true'
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-indent-right',
                'title' => __('Hidden Sidebar', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'show_hidden_sidebar',
                        'type' => 'switch',
                        'title' => __('Show hidden sidebar?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 0,
                    ),
                    array(
                        'id'=>'sidebar_position',
                        'type' => 'select',
                        'title' => __('Sidebar position?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'st_sidebar_on_left' => __('Left', 'pulse'),
                            'st_sidebar_on_right' => __('Right', 'pulse')),
                        'default' => 'st_sidebar_on_right',
                        'required' => array('show_hidden_sidebar','equals','1'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'sidebar_width',
                        'type' => 'text',
                        'title' => __('Hidden bar width', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __('Default value is 380.', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '380',
                        'class' => 'small-text',
                        'required' => array('show_hidden_sidebar','equals','1'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'sidebar_align',
                        'type' => 'select',
                        'title' => __('Hidden sidebar text alignment?', 'pulse'),
                        'subtitle' => __('Default value is centred.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => $align_array,
                        'required' => array('show_hidden_sidebar','equals','1'),
                        'default' => 'pulse_center_align',
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'background_image_sidebar',
                        'type' => 'media',
                        'title' => __('Hidden sidebar background image', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>'',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('Optional', 'pulse'),
                        'required' => array('show_hidden_sidebar','equals','1'),
                        'subtitle' => __('', 'pulse'),
                    ),
                    array(
                        'id'=>'background_color_sidebar',
                        'type' => 'color',
                        'title' => __('Hidden sidebar background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#C0C0C0',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('show_hidden_sidebar','equals','1'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'active_color_sidebar',
                        'type' => 'color',
                        'title' => __('Hidden sidebar active text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('show_hidden_sidebar','equals','1'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'body_color_sidebar',
                        'type' => 'color',
                        'title' => __('Hidden sidebar text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#AFAFAF',
                        'validate' => 'color',
                        'transparent' => false,
                        'required' => array('show_hidden_sidebar','equals','1'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'sidebar_footer_id',
                        'type' => 'select',
                        'data' => 'sidebars',
                        'title' => __('Extra sidebar ID', 'pulse'),
                        'subtitle' => __('Sidebars can be created under Appearance>Manage Sidebars', 'pulse'),
                        'desc' => __('This sidebar will be used as a footer.', 'pulse'),
                        'required' => array('show_hidden_sidebar','equals','1'),
                    ),
                    array(
                        'id'=>'opacity_sidebar_overlay',
                        'type' => 'slider',
                        'title' => __('Content overlay opacity', 'pulse'),
                        'subtitle' => __('Applicable only for when the hidden sidebar is visible.', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "25",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                        'compiler' => 'true',
                        'required' => array('show_hidden_sidebar','equals','1'),
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-fork',
                'icon_class' => 'icon-large',
                'title' => __('Footer Section', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'use_footer',
                        'type' => 'switch',
                        'title' => __('Display footer?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'footer_reveal',
                        'type' => 'switch',
                        'title' => __('Make footer position fixed?', 'pulse'),
                        'subtitle'=> __('If yes it will create a reveal effect on the footer.', 'pulse'),
                        "default"       => 0,
                    ),
                    array('id'=>'footer_font_size',
                        'type' => 'slider',
                        'title' => __('Footer body font size', 'pulse'),
                        'desc'=> __('Min: 6, max: 50', 'pulse'),
                        "default"       => "13",
                        "min"       => "8",
                        "step"      => "1",
                        "max"       => "50",
                    ),
                    array(
                        'id'=>'titles_color_footer',
                        'type' => 'color',
                        'title' => __('Footer titles and links text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'body_color_footer',
                        'type' => 'color',
                        'title' => __('Footer text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#8C9499',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'footer_border_color',
                        'type' => 'color',
                        'title' => __('Footer top border color', 'pulse'),
                        'subtitle' => __('Leave blank for no border', 'pulse'),
                        'default' => '',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'background_color_footer',
                        'type' => 'color',
                        'title' => __('Footer background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#2B2F32',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'bk_image_footer',
                        'type' => 'media',
                        'title' => __('Footer background image', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>'',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('Optional', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'footer_image_align',
                        'type' => 'select',
                        'title' => __('Background image position', 'pulse'),
                        'subtitle' => __('How the image will be aligned vertically', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'top' => __('Top','pulse'),
                            'center' => __('Center','pulse'),
                            'bottom' => __('Bottom','pulse'),
                        ),
                        'default' => 'center',
                        'required' => array('bk_image_footer','not',''),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'pattern_footer',
                        'type' => 'image_select',
                        'tiles' => true,
                        'title' => __('Footer background pattern images', 'pulse'),
                        'subtitle'=> __('Optional', 'pulse'),
                        'desc'=> __('To add more images place them inside wp-content/themes/pulse/images/patterns/', 'pulse'),
                        'default'       => '',
                        'options' => $sample_patterns,
                    ),
                    array(
                        'id'=>'bottom_page',
                        'type' => 'switch',
                        'title' => __('Add special page content before footer widgets?', 'pulse'),
                        'subtitle'=> __('Create a specific page to be used here', 'pulse'),
                        "default"       => 0,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'bottom_page_id',
                        'type' => 'select',
                        'data' => 'pages',
                        'title' => __('Page to be displayed before footer widgets?', 'pulse'),
                        'subtitle' => __('Content to be appended on the footer top section.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        "default"       => '',
                        'required' => array('bottom_page','equals','1'),
                    ),
                    array(
                        'id'=>'bottom_page_after',
                        'type' => 'switch',
                        'title' => __('Add special page content after footer widgets?', 'pulse'),
                        'subtitle'=> __('Create a specific page to be used here', 'pulse'),
                        "default"       => 0,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'bottom_page_after_id',
                        'type' => 'select',
                        'data' => 'pages',
                        'title' => __('Page to be displayed after footer widgets?', 'pulse'),
                        'subtitle' => __('Content to be appended on the footer top section.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        "default"       => '',
                        'required' => array('bottom_page_after','equals','1'),
                    ),
                    array(
                        'id'=>'bottom_sidebar',
                        'type' => 'switch',
                        'title' => __('Display footer sidebar?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'widgets_nr',
                        'type' => 'select',
                        'title' => __('Number of widgets per row?', 'pulse'),
                        'subtitle' => __('Default value is Three.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'small-12' => __('One','pulse'),
                            'small-6' => __('Two','pulse'),
                            'small-4' => __('Three','pulse'),
                            'small-3' => __('Four','pulse'),
                            'small-2' => __('Six','pulse'),
                        ),
                        'default' => 'small-3',
                        'required' => array('bottom_sidebar','equals','1'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'footer_text',
                        'type' => 'editor',
                        'title' => __('After footer text (center or left aligned)', 'pulse'),
                        'subtitle' => __('Space is limited so use very few text.', 'pulse'),
                        'default' => __('','pulse'),
                        'editor_options'   => array(
                            'teeny'            => true,
                            'textarea_rows'    => 1,
                            'media_buttons'    => false,
                            'tinymce'          => false
                        )
                    ),
                    array(
                        'id'=>'footer_text_extra',
                        'type' => 'editor',
                        'title' => __('Extra after footer text (right aligned)', 'pulse'),
                        'subtitle' => __('Space is limited so use very few text.', 'pulse'),
                        'default' => __('','pulse'),
                        'editor_options'   => array(
                            'teeny'            => true,
                            'textarea_rows'    => 1,
                            'media_buttons'    => false,
                            'tinymce'          => false
                        )
                    ),
                    array(
                        'id'=>'footer_text_background_color',
                        'type' => 'color',
                        'title' => __('After footer text background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#212427',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                )
            );

            $this->sections[] = array(
                'icon' => 'el-icon-calendar',
                'icon_class' => 'icon-large',
                'title' => __('Blog', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'custom_width_blog',
                        'type' => 'text',
                        'title' => __('Maximum blog content width', 'pulse'),
                        'subtitle' => __('In pixels.', 'pulse'),
                        'desc' => __("Will be applied only to blog pages/posts that don't have a right sidebar.", 'pulse'),
                        'validate' => 'numeric',
                        'default' => '1080',
                        'class' => 'small-text'
                    ),
                    array(
                        'id'=>'header_align_blog',
                        'type' => 'select',
                        'title' => __('Single posts default featured header text position', 'pulse'),
                        'subtitle' => __('Applies only to posts with featured media', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'topped_content' => __('Top','pulse'),
                            'middled_content' => __('Middle','pulse'),
                            'bottomed_content' => __('Bottom','pulse')),//Must provide key => value pairs for select options
                        'default' => 'bottomed_content'
                    ),
                    array(
                        'id'=>'archives_type',
                        'type' => 'select',
                        'title' => __('Blog archives page template?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'classic' => 'Classic - Big media with post information always visible',
                            'grid' => 'Image grid - Image focused with info displayed on rollover',
                            'masonry' => 'Masonry - Mosaic with post information always visible',
                            'stacked' => 'Modern - Plain text with image reveal on rollover',
                        ),
                        'default' => 'classic'
                    ),
                    array(
                        'id'=>'autoplay_blog',
                        'type' => 'switch',
                        'title' => __('Play slideshow on single posts?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array( 'id'=>'delay_blog',
                        'type' => 'text',
                        'title' => __('Slideshow delay in miliseconds', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '6500',
                        'class' => 'small-text'
                    ),
                    array(
                        'id'=>'uppercase_blog_headings',
                        'type' => 'switch',
                        'title' => __('Uppercase titles and filter labels?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'show_date_blog',
                        'type' => 'switch',
                        'title' => __('Show dates on blog?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'minread_blog',
                        'type' => 'switch',
                        'title' => __('Show "Minutes Read" text on blog?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'postedby_blog',
                        'type' => 'switch',
                        'title' => __('Show "Posted by" text on blog?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'categoriesby_blog',
                        'type' => 'switch',
                        'title' => __('Show post categories text on blog?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'show_blog_nav',
                        'type' => 'switch',
                        'title' => __('Show previous and next posts link?', 'pulse'),
                        'subtitle'=> __('Will be shown under the post content.', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'related_posts',
                        'type' => 'switch',
                        'title' => __('Show related posts?', 'pulse'),
                        'subtitle'=> __('Will be shown under the post comments section.', 'pulse'),
                        "default"       => 1,
                    ),
                    /*array(
                        'id'=>'related_posts_bk_color',
                        'type' => 'color',
                        'title' => __('Related posts background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'related_posts_border_color',
                        'type' => 'color',
                        'title' => __('Related posts border color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),*/
                    array(
                        'id'=>'related_author',
                        'type' => 'switch',
                        'title' => __('Show author info under post?', 'pulse'),
                        'subtitle'=> __('Will be shown under the post content.', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'backend_bl_sharing',
                        'type' => 'info',
                        'desc' => __('Social Sharing', 'pulse')
                    ),
                    array(
                        'id'=>'share_blog',
                        'type' => 'switch',
                        'title' => __('Show sharing buttons?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'share_blog_fb',
                        'type' => 'checkbox',
                        'required' => array('share_blog','equals','1'),
                        'title' => __('Facebook', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                    array(
                        'id'=>'share_blog_goo',
                        'type' => 'checkbox',
                        'required' => array('share_blog','equals','1'),
                        'title' => __('Google +', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                    array(
                        'id'=>'share_blog_pin',
                        'type' => 'checkbox',
                        'required' => array('share_blog','equals','1'),
                        'title' => __('Pinterest', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                    array(
                        'id'=>'share_blog_twt',
                        'type' => 'checkbox',
                        'required' => array('share_blog','equals','1'),
                        'title' => __('Twitter', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                )
            );

            $this->sections[] = array(
                'icon' => 'el-icon-camera',
                'icon_class' => 'icon-large',
                'title' => __('Portfolio', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'archives_ptype',
                        'type' => 'select',
                        'title' => __('Portfolio archives page template?', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'grid' => __('Grid with horizontal rectangular images','pulse'),
                            'grid_vertical' => __('Grid with vertical rectangular images','pulse'),
                            'squares' => __('Grid with squared images','pulse'),
                            'masonry' => __('Grid without image crop - Masonry','pulse')
                        ),
                        'default' => 'grid'
                    ),
                    array(
                        'id'=>'portfolio_layout',
                        'type' => 'select',
                        'title' => __('Default single posts layout', 'pulse'),
                        'subtitle' => __('Can be overriden individually for each post', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'half' => __('Half','pulse'),
                            'wide' => __('Wide','pulse'),
                            'wideout' => __('Full width','pulse'),
                            'custom' => __('Custom layout','pulse')),
                        'default' => array('half' => 'Half')
                    ),
                    array(
                        'id'=>'autoplay_portfolio',
                        'type' => 'switch',
                        'title' => __('Play slideshow on single posts?', 'pulse'),
                        'subtitle'=> __('Applicable only for posts with wide and half layout', 'pulse'),
                        "default"       => 1,
                    ),
                    array( 'id'=>'delay_portfolio',
                        'type' => 'text',
                        'title' => __('Slideshow delay in miliseconds', 'pulse'),
                        'subtitle' => __('Applicable only for posts with wide and half layout layout', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'numeric',
                        'default' => '6500',
                        'class' => 'small-text'
                    ),
                    array(
                        'id'=>'uppercase_folio_headings',
                        'type' => 'switch',
                        'title' => __('Uppercase titles?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 0,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'dateby_port',
                        'type' => 'switch',
                        'title' => __('Show date on single post entries?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 0,
                    ),
                    array(
                        'id'=>'categoriesby_port',
                        'type' => 'switch',
                        'title' => __('Show skills on single post entries?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'show_port_nav',
                        'type' => 'switch',
                        'title' => __('Show previous and next posts link?', 'pulse'),
                        'subtitle'=> __('Will be shown under the post content.', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'port_nav_logic',
                        'type' => 'switch',
                        'title' => esc_html__('Navigate within the same skill/category?', 'pulse'),
                        'subtitle'=> esc_html__('If ON previous and next posts link will show only posts with at least one common skill/category', 'pulse'),
                        "default"       => 1,
                        'required' => array('show_port_nav','equals','1'),
                    ),
                    array(
                        'id'=>'related_port',
                        'type' => 'switch',
                        'title' => __('Show related posts in single post pages?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'port_resp_order',
                        'type' => 'switch',
                        'title' => __('Show title and post content before media on split layout?', 'pulse'),
                        'subtitle'=> __('Mobile mode only', 'pulse'),
                        "default"       => 0,
                    ),
                    /*array(
                        'id'=>'related_port_bk_color',
                        'type' => 'color',
                        'title' => __('Related posts background color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'related_port_border_color',
                        'type' => 'color',
                        'title' => __('Related posts border color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#ffffff',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),*/
                    array(
                        'id'=>'backend_lb_overlayer',
                        'type' => 'info',
                        'desc' => __('Overlayer: will be shown above the content when a portfolio thumb is clicked', 'pulse')
                    ),
                    array(
                        'id'=>'active_color_overlayer',
                        'type' => 'color',
                        'title' => __('Overlayer active text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#494f55',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'headings_color_overlayer',
                        'type' => 'color',
                        'title' => __('Overlayer headings color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#303030',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'smallers_color_overlayer',
                        'type' => 'color',
                        'title' => __('Overlayer small headings text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#acacac',
                        'validate' => 'color',
                        'transparent' => false,
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'body_color_overlayer',
                        'type' => 'color',
                        'title' => __('Overlayer body text color', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'default' => '#303030',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'lines_color_overlayer',
                        'type' => 'color',
                        'title' => __('Overlayer divider lines color', 'pulse'),
                        'default' => '#dedede',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'background_color_overlayer',
                        'type' => 'color',
                        'title' => __('Overlayer background color', 'pulse'),
                        'default' => '#FFFFFF',
                        'validate' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id'=>'overlayer_opacity',
                        'type' => 'slider',
                        'title' => __('Overlayer background opacity', 'pulse'),
                        'desc'=> __('Min: 0, max: 100', 'pulse'),
                        "default"       => "100",
                        "min"       => "0",
                        "step"      => "5",
                        "max"       => "100",
                    ),
                    array(
                        'id'=>'backend_lb_share_folio',
                        'type' => 'info',
                        'desc' => __('Social Sharing', 'pulse')
                    ),
                    array(
                        'id'=>'share_portfolio',
                        'type' => 'switch',
                        'title' => __('Show sharing buttons?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 1,
                    ),
                    array(
                        'id'=>'share_portfolio_fb',
                        'type' => 'checkbox',
                        'required' => array('share_portfolio','equals','1'),
                        'title' => __('Facebook', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                    array(
                        'id'=>'share_portfolio_goo',
                        'type' => 'checkbox',
                        'required' => array('share_portfolio','equals','1'),
                        'title' => __('Google +', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                    array(
                        'id'=>'share_portfolio_pin',
                        'type' => 'checkbox',
                        'required' => array('share_portfolio','equals','1'),
                        'title' => __('Pinterest', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                    array(
                        'id'=>'share_portfolio_twt',
                        'type' => 'checkbox',
                        'required' => array('share_portfolio','equals','1'),
                        'title' => __('Twitter', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '1'
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-envelope',
                'icon_class' => 'icon-large',
                'title' => __('Google Maps API Key', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'google_maps_key',
                        'type' => 'text',
                        'title' => __('Google Maps API Key', 'pulse'),
                        'subtitle' => __('More info here https://developers.google.com/maps/pricing-and-plans/standard-plan-2016-update', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => '',
                        'class' => ''
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-search',
                'icon_class' => 'icon-large',
                'title' => __('Search Results', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'search_image',
                        'type' => 'media',
                        'title' => __('Header image', 'pulse'),
                        'compiler' => 'true',
                        'default'=> array(
                            'url'=>'',
                            'id'=>'',
                            'width'=>'',
                            'height'=>'',
                        ),
                        'desc'=> __('Optional', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'compiler' => 'true'
                    ),
                    array(
                        'id'=>'search_layout',
                        'type' => 'select',
                        'title' => __('General display', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'options' => array(
                            'classic' => 'Classic',
                            //'grid' => 'Image grid - Image focused with info displayed on rollover',
                            'masonry' => 'Masonry',
                            //'stacked' => 'Modern - Plain text with image reveal on rollover',
                        ),
                        'default' => 'classic'
                    ),
                    array(
                        'id'=>'search_right_sidebar',
                        'type' => 'switch',
                        'title' => __('Display right sidebar on search page?', 'pulse'),
                        'subtitle'=> __('', 'pulse'),
                        "default"       => 0,//WAS
                        'compiler' => 'true'
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-comment',
                'icon_class' => 'icon-large',
                'title' => __('Translations', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'theme_translation',
                        'type' => 'switch',
                        'title' => __('Translate using .mo files?', 'pulse'),
                        'subtitle'=> __('If yes is selected the values below will be ignored. If WPML plugin is active the values below will be overriden too.', 'pulse'),
                        "default" => 0,
                    ),
                    array(
                        'id'=>'backend_tr_general',
                        'type' => 'info',
                        'desc' => __('General', 'pulse')
                    ),
                    array(
                        'id'=>'theme_divider',
                        'type' => 'text',
                        'title' => __('Text separator', 'pulse'),
                        'subtitle' => __('Used on multiple parts of the theme to divide pieces of text', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('-','pulse')
                    ),
                    array(
                        'id'=>'search_tip_text',
                        'type' => 'text',
                        'title' => __('Search field tip text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Search this website...','pulse')
                    ),
                    array(
                        'id'=>'submit_search_res_title',
                        'type' => 'text',
                        'title' => __('Search results page title text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Search Results for', 'pulse')
                    ),
                    array(
                        'id'=>'submit_search_no_results',
                        'type' => 'text',
                        'title' => __('Search results - no results found text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('No Results Found for', 'pulse')
                    ),
                    array(
                        'id'=>'search_help_1',
                        'type' => 'text',
                        'title' => __('New search help text - title', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Sorry, but it seems that there are no results... Maybe you can try again?', 'pulse')
                    ),
                    array(
                        'id'=>'search_help_2',
                        'type' => 'text',
                        'title' => __('New search help text - still looking for something else text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Still looking for something else?', 'pulse')
                    ),
                    array(
                        'id'=>'search_help_3',
                        'type' => 'text',
                        'title' => __('New search help text - double check your spelling text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Double check your spelling', 'pulse')
                    ),
                    array(
                        'id'=>'search_help_4',
                        'type' => 'text',
                        'title' => __('New search help text - Try using single words text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Try using single words (e.g. painting, book)', 'pulse')
                    ),
                    array(
                        'id'=>'search_help_5',
                        'type' => 'text',
                        'title' => __('New search help text - Try searching for something that is less specific text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Try searching for something that is less specific', 'pulse')
                    ),
                    array(
                        'id'=>'previous_text',
                        'type' => 'text',
                        'title' => __('Previous entries text', 'pulse'),
                        'subtitle' => __('Will be used on navigation buttons', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Previous','pulse')
                    ),
                    array(
                        'id'=>'next_text',
                        'type' => 'text',
                        'title' => __('Next entries text', 'pulse'),
                        'subtitle' => __('Will be used on navigation buttons', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Next','pulse')
                    ),
                    array(
                        'id'=>'required_text',
                        'type' => 'text',
                        'title' => __('Required text', 'pulse'),
                        'subtitle' => __('Used on mandatory fields.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __(' (required)', 'pulse')
                    ),
                    array(
                        'id'=>'profile_text',
                        'type' => 'text',
                        'title' => __('Members view profile link text', 'pulse'),
                        'subtitle' => __('Shown under each member image and description', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('View Profile', 'pulse'),
                    ),
                    array(
                        'id'=>'in_touch_text',
                        'type' => 'text',
                        'title' => __('Get in touch text', 'pulse'),
                        'subtitle' => __('Used near team member social network buttons.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Get In touch', 'pulse')
                    ),
                    /*array(
                        'id'=>'filter_text',
                        'type' => 'text',
                        'title' => __('Filter text', 'pulse'),
                        'subtitle' => __('Used on blog and portfolio filter buttons.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Filter', 'pulse')
                    ),*/
                    array(
                        'id'=>'backend_tr_error_page',
                        'type' => 'info',
                        'desc' => __('404 Error Page', 'pulse')
                    ),
                    array(
                        'id'=>'404_title_text',
                        'type' => 'text',
                        'title' => __('Page title text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('NOT FOUND','pulse')
                    ),
                    array(
                        'id'=>'404_body_text',
                        'type' => 'textarea',
                        'title' => __('Page body text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                        'default' => __('Ooops... Something went terribly wrong!','pulse')
                    ),
                    array(
                        'id'=>'backend_tr_blog',
                        'type' => 'info',
                        'desc' => __('Blog', 'pulse')
                    ),
                    array(
                        'id'=>'read_more',
                        'type' => 'text',
                        'title' => __('Read more button text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Read More', 'pulse')
                    ),
                    array(
                        'id'=>'sticky_text',
                        'type' => 'text',
                        'title' => __('Sticky post text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Sticky Post', 'pulse')
                    ),
                    array(
                        'id'=>'min_read_text',
                        'type' => 'text',
                        'title' => __('Minutes read text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('MIN READ', 'pulse')
                    ),
                    array(
                        'id'=>'posted_by_text',
                        'type' => 'text',
                        'title' => __('Posted by text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Posted by', 'pulse')
                    ),
                    array(
                        'id'=>'on_text',
                        'type' => 'text',
                        'title' => __('On text', 'pulse'),
                        'subtitle' => __('Will be used on some blog sentences.', 'pulse'),
                        'desc' => __('Posted on Jan 13th.', 'pulse'),
                        'default' => __('on','pulse')
                    ),
                    array(
                        'id'=>'about_author_text',
                        'type' => 'text',
                        'title' => __('About text', 'pulse'),
                        'subtitle' => __('Displayed before post author name.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('About', 'pulse')
                    ),
                    /*array(
                        'id'=>'to_blog',
                        'type' => 'text',
                        'title' => __('Back to Blog button text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('To Blog', 'pulse')
                    ),*/
                    array(
                        'id'=>'older',
                        'type' => 'text',
                        'title' => __('Older posts text', 'pulse'),
                        'subtitle' => __('Used for navigation on parent blog pages.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Older posts', 'pulse')
                    ),
                    array(
                        'id'=>'newer',
                        'type' => 'text',
                        'title' => __('Newer posts text', 'pulse'),
                        'subtitle' => __('Used for navigation on parent blog pages.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Newer posts', 'pulse')
                    ),
                    array(
                        'id'=>'related_posts_text',
                        'type' => 'text',
                        'title' => __('Single posts pages - related posts text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Related News', 'pulse')
                    ),
                    array(
                        'id'=>'related_posts_teaser_text',
                        'type' => 'text',
                        'title' => __('Single posts pages - related posts sub-heading text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Other posts that you should not miss.', 'pulse')
                    ),
                    array(
                        'id'=>'older_single',
                        'type' => 'text',
                        'title' => __('Single posts pages - previous post text', 'pulse'),
                        'subtitle' => __('Used for navigation on single post pages.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('&larr; PREVIOUS POST', 'pulse')
                    ),
                    array(
                        'id'=>'newer_single',
                        'type' => 'text',
                        'title' => __('Single posts pages - next post text', 'pulse'),
                        'subtitle' => __('Used for navigation on single post pages.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('NEXT POST &rarr;', 'pulse')
                    ),
                    array(
                        'id'=>'all_the_posts',
                        'type' => 'text',
                        'title' => __('Archives pages', 'pulse'),
                        'subtitle' => __('Subheading text', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('All the posts published.', 'pulse')
                    ),
                    array(
                        'id'=>'backend_tr_portfolio',
                        'type' => 'info',
                        'desc' => __('Portfolio', 'pulse')
                    ),
                    array(
                        'id'=>'prj_desc_text',
                        'type' => 'text',
                        'title' => __('Project description text', 'pulse'),
                        'subtitle' => __('Will be displayed just above the project text.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('About this project','pulse')
                    ),
                    array(
                        'id'=>'date_text',
                        'type' => 'text',
                        'title' => __('Date text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Date','pulse')
                    ),
                    array(
                        'id'=>'client_text',
                        'type' => 'text',
                        'title' => __('Client description text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Client','pulse')
                    ),
                    array(
                        'id'=>'extra_fld1',
                        'type' => 'text',
                        'title' => esc_html__('Extra field 1 - Description text', 'pulse'),
                        'subtitle' => esc_html__('', 'pulse'),
                        'desc' => esc_html__('', 'pulse'),
                        'default' => esc_html__('My Custom Field 1','pulse')
                    ),
                    array(
                        'id'=>'extra_fld2',
                        'type' => 'text',
                        'title' => esc_html__('Extra field 2 - Description text', 'pulse'),
                        'subtitle' => esc_html__('', 'pulse'),
                        'desc' => esc_html__('', 'pulse'),
                        'default' => esc_html__('My Custom Field 2','pulse')
                    ),
                    array(
                        'id'=>'extra_fld3',
                        'type' => 'text',
                        'title' => esc_html__('Extra field 3 - Description text', 'pulse'),
                        'subtitle' => esc_html__('', 'pulse'),
                        'desc' => esc_html__('', 'pulse'),
                        'default' => esc_html__('My Custom Field 3','pulse')
                    ),
                    array(
                        'id'=>'skills_text',
                        'type' => 'text',
                        'title' => __('Category description text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Skills','pulse')
                    ),
                    array(
                        'id'=>'tags_text',
                        'type' => 'text',
                        'title' => __('Tag description text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Tags','pulse')
                    ),
                    array(
                        'id'=>'project_text',
                        'type' => 'text',
                        'title' => __('Project link header text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Project URL','pulse')
                    ),
                    array(
                        'id'=>'launch_text',
                        'type' => 'text',
                        'title' => __('Project link button text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Launch Project','pulse')
                    ),
                    /*array(
                        'id'=>'prj_info_text',
                        'type' => 'text',
                        'title' => __('Open project text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Open Project','pulse')
                    ),*/
                    array(
                        'id'=>'all_text',
                        'type' => 'text',
                        'title' => __('All text', 'pulse'),
                        'subtitle' => __('Used on filters. Will show all posts on current page.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('All', 'pulse')
                    ),
                    array(
                        'id'=>'load_more',
                        'type' => 'text',
                        'title' => __('Load more posts text', 'pulse'),
                        'subtitle' => __('Will be shown under the posts grid.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('LOAD MORE POSTS', 'pulse')
                    ),
                    array(
                        'id'=>'no_more',
                        'type' => 'text',
                        'title' => __('No more posts to show text', 'pulse'),
                        'subtitle' => __('Will be shown under the posts grid.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('NO MORE POSTS TO SHOW', 'pulse')
                    ),
                    array(
                        'id'=>'related_prj_text',
                        'type' => 'text',
                        'title' => __('Related projects text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Related Projects', 'pulse')
                    ),
                    array(
                        'id'=>'related_prj_teaser_text',
                        'type' => 'text',
                        'title' => __('Related projects sub-heading text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Simply delivering amazing stuff. Period.', 'pulse')
                    ),
                    /*array(
                        'id'=>'to_portfolio',
                        'type' => 'text',
                        'title' => __('Back to Portfolio button text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('To Portfolio', 'pulse')
                    ),*/
                    array(
                        'id'=>'prj_prev_text',
                        'type' => 'text',
                        'title' => __('Single posts pages - previous post text', 'pulse'),
                        'subtitle' => __('Used for navigation on single post pages.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('PREVIOUS PROJECT', 'pulse')
                    ),
                    array(
                        'id'=>'prj_next_text',
                        'type' => 'text',
                        'title' => __('Single posts pages - next post text', 'pulse'),
                        'subtitle' => __('Used for navigation on single post pages.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('NEXT PROJECT', 'pulse')
                    ),
                    /*array(
                        'id'=>'prj_close_text',
                        'type' => 'text',
                        'title' => __('Close lightbox text', 'pulse'),
                        'subtitle' => __('Used when the portfolio lightbox is opened.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('CLOSE', 'pulse')
                    ),*/
                    array(
                        'id'=>'all_the_portfolios',
                        'type' => 'text',
                        'title' => __('Archives pages', 'pulse'),
                        'subtitle' => __('Subheading text', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('All the work completed.', 'pulse')
                    ),
                    array(
                        'id'=>'backend_tr_comments',
                        'type' => 'info',
                        'desc' => __('Comments Section', 'pulse')
                    ),
                    array(
                        'id'=>'comments_label', 'type' => 'text',
                        'title' => __('Comments title text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Comments', 'pulse')
                    ),
                    array(
                        'id'=>'comments_no_response',
                        'type' => 'text',
                        'title' => __('Zero comments text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('No comments', 'pulse')
                    ),
                    array(
                        'id'=>'comments_one_response',
                        'type' => 'text',
                        'title' => __('One comment text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('1 Comment', 'pulse')
                    ),
                    array(
                        'id'=>'comments_oneplus_response',
                        'type' => 'text',
                        'title' => __('Multiple comments text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Comments', 'pulse')
                    ),
                    array(
                        'id'=>'backend_tr_respond',
                        'type' => 'info',
                        'desc' => __('Respond Section', 'pulse')
                    ),
                    array(
                        'id'=>'reply_text',
                        'type' => 'text',
                        'title' => __('Reply text', 'pulse'),
                        'subtitle' => __('Used on buttons.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Reply', 'pulse')
                    ),
                    array(
                        'id'=>'comments_leave_reply',
                        'type' => 'text',
                        'title' => __('Text to ask the user to leave a reply', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Leave a Comment', 'pulse')
                    ),
                    array(
                        'id'=>'comments_under_reply',
                        'type' => 'text',
                        'title' => __('Compementary text shown under the leave a reply text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Your feedback is valuable for us. Your email will not be published.', 'pulse')
                    ),
                    array(
                        'id'=>'comments_author_text',
                        'type' => 'text',
                        'title' => __('Name input field text', 'pulse'),
                        'subtitle' => __('This text will be displayed inside the author input textfield.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Name', 'pulse')
                    ),
                    array(
                        'id'=>'comments_email_text',
                        'type' => 'text',
                        'title' => __('Email input field text', 'pulse'),
                        'subtitle' => __('This text will be displayed inside the email input textfield.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Email', 'pulse')
                    ),
                    array(
                        'id'=>'comments_url_text',
                        'type' => 'text',
                        'title' => __('URL input field text', 'pulse'),
                        'subtitle' => __('This text will be displayed inside the URL input textfield.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Website', 'pulse')
                    ),
                    array(
                        'id'=>'comments_comment_text',
                        'type' => 'text',
                        'title' => __('Comment input textarea text', 'pulse'),
                        'subtitle' => __('This text will be displayed inside the comment input textarea.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Your comment', 'pulse')
                    ),
                    array(
                        'id'=>'comments_submit',
                        'type' => 'text',
                        'title' => __('Submit comment button text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Submit Comment', 'pulse')
                    ),
                    array(
                        'id'=>'empty_text_error',
                        'type' => 'text',
                        'title' => __('Empty text error message', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Error! This field is required.', 'pulse')
                    ),
                    array(
                        'id'=>'invalid_email_error',
                        'type' => 'text',
                        'title' => __('Invalid email error message', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Error! Invalid email.', 'pulse')
                    ),
                    array( 'id'=>'comment_ok_message',
                        'type' => 'text',
                        'title' => __('Comment submitted text', 'pulse'),
                        'subtitle' => __('This text is displayed after the comment is submitted.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Thank you for your feedback!', 'pulse')
                    ),
                    array(
                        'id'=>'backend_tr_respond',
                        'type' => 'info',
                        'desc' => __('Contact Page', 'pulse')
                    ),
                    array(
                        'id'=>'contact_subject_text',
                        'type' => 'text',
                        'title' => __('Subject help text', 'pulse'),
                        'subtitle' => __('This text will be displayed inside of the subject input textfield. The name and email fields are the same as defined before for the comments section.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Subject', 'pulse')
                    ),
                    array(
                        'id'=>'contact_message_text',
                        'type' => 'text', 'title' => __('Message help text', 'pulse'),
                        'subtitle' => __('This text will be displayed inside of the message input textfield.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Your message', 'pulse')
                    ),
                    array(
                        'id'=>'contact_submit',
                        'type' => 'text', 'title' => __('Submit button text', 'pulse'),
                        'subtitle' => __('', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Send Message','pulse')
                    ),
                    array(
                        'id'=>'contact_error_text',
                        'type' => 'text',
                        'title' => __('Error message for empty field', 'pulse'),
                        'subtitle' => __('This text will be displayed when a mandatory input field is empty.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Error! This field is required.', 'pulse')
                    ),
                    array(
                        'id'=>'contact_error_email_text',
                        'type' => 'text',
                        'title' => __('Error message for invalid email', 'pulse'),
                        'subtitle' => __('This text will be displayed when the entered email is invalid.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Error! This email is not valid.', 'pulse')
                    ),
                    array(
                        'id'=>'contact_wait_text',
                        'type' => 'text',
                        'title' => __('Form submission: Wait message', 'pulse'),
                        'subtitle' => __('This text will be displayed right after the send message button is clicked and only until the email is sent.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Please wait...', 'pulse')
                    ),
                    array(
                        'id'=>'contact_ok_text',
                        'type' => 'text',
                        'title' => __('Form submission: Ok message', 'pulse'),
                        'subtitle' => __('This text will be displayed after sending the email.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default' => __('Thank you for contacting us. We will reply soon!', 'pulse')
                    ),
                )
            );
            if ( class_exists( 'woocommerce' ) ) {
                $this->sections[] = array(
                    'icon' => 'el-icon-shopping-cart',
                    'icon_class' => 'icon-large',
                    'title' => __('Woocommerce', 'pulse'),
                    'fields' => array(
                        array(
                            'id'=>'woo_subheading',
                            'type' => 'text',
                            'title' => __('Shop page subheadings', 'pulse'),
                            'subtitle' => __('Will be displayed under the shop page title', 'pulse'),
                            'desc' => __('Optional', 'pulse'),
                            'default' => __('A stunning place to get your stuff the easy way.', 'pulse'),
                        ),
                        array(
                            'id'=>'woo_col_nr',
                            'type' => 'select',
                            'title' => __('Number of products per row?', 'pulse'),
                            'subtitle' => __('Default value is Four.', 'pulse'),
                            'desc' => __('', 'pulse'),
                            'options' => array('2' => __('Two', 'pulse'),'3' => __('Three', 'pulse'),'4' => __('Four', 'pulse')),
                            'default' => '4',
                            'compiler' => 'true'
                        ),
                        array(
                            'id'=>'woo_sidebar_display',
                            'type' => 'switch',
                            'title' => __('Display right sidebar by default?', 'pulse'),
                            'subtitle'=> __("This option will apply only to WooCommerce Core Pages that aren't set up using shortcodes. If you want to display/hide a sidebar on a specific page add ?sidebar=y or ?sidebar=n to your link URL", 'pulse'),
                            "default"       => 1,
                        ),
                        array(
                            'id'=>'woo_cart_display',
                            'type' => 'switch',
                            'title' => __('Add Shopping Cart info to the main menu?', 'pulse'),
                            'subtitle' => __('', 'pulse'),
                            "default"       => 1,
                            'desc' => __('', 'pulse'),
                        ),
                        array(
                            'id'=>'woo_cart_always_display',
                            'type' => 'switch',
                            'title' => __('Show Shopping Cart info even when it is empty?', 'pulse'),
                            'subtitle'=> __("", 'pulse'),
                            "default"       => 0,
                            'required' => array('woo_cart_display','equals','1'),
                        ),
                        array(
                            'id'=>'woo_cart_info',
                            'type' => 'select',
                            'title' => __('Cart information?', 'pulse'),
                            'subtitle'=> __("", 'pulse'),
                            'options' => array('items' => __('Items', 'pulse'),'price' => __('Price', 'pulse'),'both' => __('Both', 'pulse')),
                            'default' => array('price' => 'Price'),
                            'required' => array('woo_cart_display','equals','1'),
                        ),
                    )
                );
            }
            $this->sections[] = array(
                'icon' => 'el-icon-wrench',
                'icon_class' => 'icon-large',
                'title' => __('Custom Scripts', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'css_text',
                        'type' => 'ace_editor',
                        'mode'     => 'css',
                        'theme'    => 'monokai',
                        'title' => __('Custom CSS', 'pulse'),
                        'subtitle' => __('Quickly add some CSS to your theme by adding it to this block.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'default'       => '',
                        'validate' => 'css',
                    ),
                    array(
                        'id'=>'js_text',
                        'type' => 'ace_editor',
                        'mode'     => 'javascript',
                        'theme'    => 'monokai',
                        'title' => __('Custom Javascript', 'pulse'),
                        'subtitle' => __('Add some js scripting here', 'pulse'),
                        'desc' => "For object targeting use 'jQuery' prefix instead of the default '$' notation.",
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'el-icon-key',
                'icon_class' => 'icon-large',
                'title' => __('Advanced settings', 'pulse'),
                'fields' => array(
                    array(
                        'id'=>'info_warning_slugs',
                        'type'=>'info',
                        'style'=>'warning',
                        'header'=> __( 'This is a header.','pulse'),
                        'desc' => __( "If slug changes don't apply immediately it is related to WordPress permalinks. After making your changes here you need to go to Settings>Reading and change permalinks structure to default. Save changes and then revert it to previous state.", 'pulse')
                    ),
                    array(
                        'id'=>'portfolio_slug',
                        'type' => 'text',
                        'title' => __('Portfolios slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'portfolios'
                    ),
                    array(
                        'id'=>'skills_slug',
                        'type' => 'text',
                        'title' => __('Skills slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('Portfolio hierarchical category', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'skills'
                    ),
                    array(
                        'id'=>'folio_tags_slug',
                        'type' => 'text',
                        'title' => __('Portfolio tag slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('Portfolio non-hierarchical category', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'tagged'
                    ),
                    array(
                        'id'=>'slides_slug',
                        'type' => 'text',
                        'title' => __('Slides slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'slides'
                    ),
                    array(
                        'id'=>'groups_slug',
                        'type' => 'text',
                        'title' => __('Slides groups slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('Slides hierarchical category', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'group'
                    ),
                    array(
                        'id'=>'members_slug',
                        'type' => 'text',
                        'title' => __('Members slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'member'
                    ),
                    array(
                        'id'=>'team_slug',
                        'type' => 'text',
                        'title' => __('Team slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('Members hierarchical category', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'team'
                    ),
                    array(
                        'id'=>'testimonials_slug',
                        'type' => 'text',
                        'title' => __('Testimonials slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'testimonials'
                    ),
                    array(
                        'id'=>'testimonials_groups_slug',
                        'type' => 'text',
                        'title' => __('Testimonials groups slug', 'pulse'),
                        'subtitle' => __('No special characters and must be unique.', 'pulse'),
                        'desc' => __('Testimonials hierarchical category', 'pulse'),
                        'validate' => 'no_special_chars',
                        'default' => 'testimonials_group'
                    ),
                    array(
                        'id'=>'backend_tr_vc_light',
                        'type' => 'info',
                        'desc' => __('WPBakery Page Builder integration.', 'pulse')
                    ),
                    array(
                        'id'=>'pulse_light_vc',
                        'type' => 'switch',
                        'title' => __('Use light version of WPBakery Page Builder?', 'pulse'),
                        'subtitle'=> __("It is strongly recommended that you keep this option ON. If you decide to use the theme WPBakery Page Builder regular/heavy version, the website load speed will be higher and some of the elements may not work properly.", 'pulse'),
                        "default"       => 1,
                    ),
                )
            );

            $this->sections[] = array(
                'title'     => __('Import / Export', 'pulse'),
                'desc'      => __('Import and Export your Redux Framework settings from file, text or URL.', 'pulse'),
                'icon'      => 'el-icon-refresh',
                'fields'    => array(
                    array(
                        'id'            => 'opt-import-export',
                        'type'          => 'import_export',
                        'title'         => __('Import Export', 'pulse'),
                        'subtitle'      => __('Save and restore your Redux options', 'pulse'),
                        'full_width'    => false,
                    ),
                ),
            );

            $this->sections[] = array(
                'type' => 'divide',
            );

            $this->sections[] = array(
                'icon'      => 'el-icon-info-sign',
                'title'     => __('Theme Information', 'pulse'),
                'desc'      => __('<p class="description">Pulse - Hybrid WordPress Theme</p>', 'pulse'),
                'fields'    => array(
                    array(
                        'id'        => 'opt-raw-info',
                        'type'      => 'raw',
                        'content'   => $item_info,
                    )
                ),
            );

            if (false) {
                $tabs['docs'] = array(
                    'icon'      => 'el-icon-book',
                    'title'     => __('Documentation', 'pulse'),
                    'content'   => nl2br('README.html')
                );
            }
        }

        public function setHelpTabs() {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-1',
                'title'     => __('Theme Information 1', 'pulse'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'pulse')
            );

            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-2',
                'title'     => __('Theme Information 2', 'pulse'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'pulse')
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'pulse');
        }

        /**

        All the possible arguments for Redux.
        For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'          => 'prk_pulse_options',            // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'      => __("Theme Control Panel","pulse"),
                'display_version'   => $theme->get('Version'),  // Version that appears at the top of your panel
                'menu_type'         => 'menu',                  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'    => true,                    // Show the sections below the admin menu item or not
                'menu_title'        => __('Theme Options', 'pulse'),
                'page_title'        => __('Theme Options', 'pulse'),

                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => '', // Must be defined to add google fonts to the typography module

                'async_typography'  => false,                    // Use a asynchronous font on the front end or font string
                'admin_bar'         => true,                    // Show the panel pages on the admin bar
                'global_variable'   => '',                      // Set a different name for your global variable other than the opt_name
                'dev_mode'          => false,                    // Show the time the page took to load, etc
                'customizer'        => true,                    // Enable basic customizer support

                // OPTIONAL -> Give you extra features
                'page_priority'     => null,                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'       => 'themes.php',            // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions'  => 'manage_options',        // Permissions needed to access the options panel.
                'menu_icon'         => '',                      // Specify a custom URL to an icon
                'last_tab'          => '',                      // Force your panel to always open to a specific tab (by id)
                'page_icon'         => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
                'page_slug'         => '_options',              // Page slug used to denote the panel
                'save_defaults'     => true,                    // On load save the defaults to DB before user clicks save or not
                'default_show'      => false,                   // If true, shows the default value next to each field that is not the default value.
                'default_mark'      => '',                      // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,                   // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time'    => 60 * MINUTE_IN_SECONDS,
                'output'            => false,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'        => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'              => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info'           => false, // REMOVE

                // HINTS
                'hints' => array(
                    'icon'          => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'         => 'light',
                        'shadow'        => true,
                        'rounded'       => false,
                        'style'         => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show'          => array(
                            'effect'        => 'slide',
                            'duration'      => '500',
                            'event'         => 'mouseover',
                        ),
                        'hide'      => array(
                            'effect'    => 'slide',
                            'duration'  => '500',
                            'event'     => 'click mouseleave',
                        ),
                    ),
                )
            );

            // Add content after the form.
            $this->args['footer_text'] = __('','pulse');
        }

    }

    global $reduxConfig;
    $reduxConfig = new pulse_options_config();
}

/**
Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')):
    function redux_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')):
    function redux_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $value = 'just testing';

        /*
          do your validation

          if(something) {
            $value = $value;
          } elseif(something else) {
            $error = true;
            $value = $existing_value;
            $field['msg'] = 'your custom error message';
          }
         */

        $return['value'] = $value;
        if ($error == true) {
            $return['error'] = $field;
        }
        return $return;
    }
endif;
